@@ -1,7 +1,7 @@
 """
 Type annotations for dataexchange service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/literals/)
 
 Usage::
 
@@ -33,8 +33,11 @@ __all__ = (
     "ServerSideEncryptionTypesType",
     "StateType",
     "TypeType",
+    "DataExchangeServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -68,6 +71,7 @@ TypeType = Literal[
     "IMPORT_ASSETS_FROM_S3",
     "IMPORT_ASSET_FROM_SIGNED_URL",
 ]
+DataExchangeServiceName = Literal["dataexchange"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -101,6 +105,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -355,6 +360,18 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_data_set_revisions",
     "list_data_sets",
@@ -362,3 +379,16 @@ PaginatorName = Literal[
     "list_jobs",
     "list_revision_assets",
 ]
+RegionName = Literal[
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "eu-central-1",
+    "eu-west-1",
+    "eu-west-2",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
